@@ -6,6 +6,13 @@
 
 class ErrorAnalysisDashboardInterface(object):
     """Dictionary properties shared between python and javascript object."""
-    TREE_URL = "treeUrl"
-    MATRIX_URL = "matrixUrl"
+    TREE_URL = 'treeUrl'
+    MATRIX_URL = 'matrixUrl'
     ENABLE_PREDICT = 'enablePredict'
+    METHOD = 'method'
+
+
+class MethodConstants(object):
+    REGRESSION = 'regression'
+    MULTICLASS = 'multiclass'
+    BINARY = 'binary'
