@@ -15,12 +15,13 @@ from responsibleai._input_processing import _convert_to_list
 from responsibleai._interfaces import ErrorAnalysisData
 from responsibleai.serialization_utilities import serialize_json_safe
 
-from .constants import ModelTask, SKLearn
+from .constants import ModelTask
 from .error_analysis_constants import (ErrorAnalysisDashboardInterface,
                                        MethodConstants)
 from .error_handling import _format_exception
 from .explanation_constants import (ExplanationDashboardInterface,
                                     WidgetRequestResponseConstants)
+from .utils import _is_classifier
 
 FEATURE_NAMES = ExplanationDashboardInterface.FEATURE_NAMES
 ENABLE_PREDICT = ErrorAnalysisDashboardInterface.ENABLE_PREDICT
@@ -61,20 +62,20 @@ class ErrorAnalysisDashboardInput:
         (# examples x # features), the same samples
             used to build the explanation.
             Will overwrite any set on explanation object already.
-        :type dataset: numpy.array or list[][] or pandas.DataFrame
+        :type dataset: numpy.ndarray or list[][] or pandas.DataFrame
         :param true_y: The true labels for the provided explanation.
             Will overwrite any set on explanation object already.
-        :type true_y: numpy.array or list[] or pandas.Series
+        :type true_y: numpy.ndarray or list[] or pandas.Series
         :param classes: The class names.
-        :type classes: numpy.array or list[]
+        :type classes: numpy.ndarray or list[]
         :param features: Feature names.
-        :type features: numpy.array or list[]
+        :type features: numpy.ndarray or list[]
         :param categorical_features: The categorical feature names.
         :type categorical_features: list[str]
         :param true_y_dataset: The true labels for the provided dataset.
         Only needed if the explanation has a sample of instances from the
         original dataset.  Otherwise specify true_y parameter only.
-        :type true_y_dataset: numpy.array or list[] or pandas.Series
+        :type true_y_dataset: numpy.ndarray or list[] or pandas.Series
         :param pred_y: The predicted y values, can be passed in as an
             alternative to the model and explanation for a more limited
             view.
@@ -83,7 +84,7 @@ class ErrorAnalysisDashboardInput:
             Only needed if providing a sample dataset for the UI while using
             the full dataset for the tree view and heatmap. Otherwise specify
             pred_y parameter only.
-        :type pred_y_dataset: numpy.array or list[] or pandas.Series
+        :type pred_y_dataset: numpy.ndarray or list[] or pandas.Series
         :param model_task: Optional parameter to specify whether the model
             is a classification or regression model. In most cases, the
             type of the model can be inferred based on the shape of the
@@ -134,9 +135,7 @@ class ErrorAnalysisDashboardInput:
         self._string_ind_data = None
         self._categories = []
         self._categorical_indexes = []
-        self._is_classifier = model is not None\
-            and hasattr(model, SKLearn.PREDICT_PROBA) and \
-            model.predict_proba is not None
+        self._is_classifier = _is_classifier(model)
         self._dataframeColumns = None
         self.dashboard_input = {}
         has_explanation = explanation is not None
@@ -237,8 +236,8 @@ class ErrorAnalysisDashboardInput:
                                  " feature names length differs"
                                  " from local explanations dimension")
             self.dashboard_input[FEATURE_NAMES] = features
-        if model_available and hasattr(model, SKLearn.PREDICT_PROBA) \
-                and model.predict_proba is not None and dataset is not None:
+        if model_available and _is_classifier(model) and \
+                dataset is not None:
             try:
                 probability_y = model.predict_proba(dataset)
             except Exception as ex:
